@@ -4,6 +4,7 @@ from __future__ import unicode_literals
 from django.core.urlresolvers import reverse_lazy
 from django.views.generic import (
     CreateView, DetailView, DeleteView, ListView, UpdateView)
+from django.utils.encoding import force_text
 
 from .models import Pizza
 
@@ -36,3 +37,6 @@ class PizzaDeleteView(DeleteView):
 
     model = Pizza
     success_url = reverse_lazy('pizza:deleted')
+
+    def get_success_url(self):
+        return force_text(self.success_url)
